import type { RequestEvent, ResolveOptions } from '@sveltejs/kit/types';
import type { CookieSerializeOptions } from 'cookie';
import type { Simplify } from 'type-fest';
export interface Store {
    set(key: string, value: any, ttl?: number): Promise<void>;
    get(key: string): Promise<unknown>;
    update(key: string, value: any, ttl?: number): Promise<void>;
    delete(key: string): Promise<void>;
    clear(): Promise<void>;
    keys(): Promise<string[]>;
}
declare class SvelteKitSession<T> {
    private sessionData;
    private sessionId;
    private sessionName;
    private sessionManager;
    private requestEvent;
    constructor(data: T, sessionId: string, sessionName: string, sessionManager: SessionManager, requestEvent: RequestEvent);
    get data(): { [KeyType_1 in keyof T]: T[KeyType_1]; };
    set data(value: { [KeyType_1 in keyof T]: T[KeyType_1]; });
    get id(): string;
    destroy(): Promise<void>;
}
export type Session<T> = Simplify<T & SvelteKitSession<T>>;
export type SessionOptions = {
    /**
     * Number of seconds until the session expires.
     */
    ttl: number;
    /** @defaultValue `true`
     * If true, the session will be refreshed on every request.
     */
    refreshSession?: boolean;
    /** @defaultValue `sessionId`
     * The name of the session cookie
     */
    name?: string;
};
export type CookieOptions = Omit<CookieSerializeOptions, 'expires' | 'maxAge'>;
export declare class SessionManager {
    /**
     * @param sessionOptions - Session options
     * @param store - compatible store
     * @param cookieOptions - cookie options
     */
    private store;
    private ttl;
    private name;
    private readonly cookieOptions;
    private refreshSession;
    constructor(sessionOptions: SessionOptions, store: Store, cookieOptions?: CookieOptions);
    /**
     *
     * @param cookieOptions
     * @returns override cookie options for this request
     */
    private getCookieOptions;
    /**
     * **!!!!** - Use `Session.destroy()` if you want to delete the session from the store and destroy the cookie. - **!!!!**
     *
     * Deletes the session from the store
     *
     * Only pass in `sessionId`
     * @param sessionId - session id
     * @param requestEvent - !! Don't pass this !!
     */
    deleteSession(sessionId: string, requestEvent?: RequestEvent): Promise<void>;
    createSession(session: any, requestEvent: RequestEvent): Promise<any>;
    getSession(cookiesOrSessionId: string | RequestEvent['cookies']): Promise<unknown>;
    private updateSession;
    private handleSession;
    private resolve;
    listSessions(): Promise<string[]>;
    deleteAllSessions(): Promise<void>;
}
export declare function handleSession(sessionManager: SessionManager): ({ event, resolve }: {
    event: RequestEvent<Partial<Record<string, string>>, string | null>;
    resolve(event: RequestEvent<Partial<Record<string, string>>, string | null>, opts?: ResolveOptions | undefined): import("@sveltejs/kit/types/private").MaybePromise<Response>;
}) => Promise<Response>;
export default SessionManager;
